==> apache-cloudstack-4.15.2.0-src.tar.bz2: apache-cloudstack-4.15.2.0-src/engine/components-api/src/main/java/com/cloud/vm/VmWork.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
package com.cloud.vm;

import java.io.Serializable;

public class VmWork implements Serializable {
    private static final long serialVersionUID = -6946320465729853589L;

    long userId;
    long accountId;
    long vmId;

    String handlerName;

    public VmWork(long userId, long accountId, long vmId, String handlerName) {
        this.userId = userId;
        this.accountId = accountId;
        this.vmId = vmId;
        this.handlerName = handlerName;
    }

    public long getUserId() {
        return userId;
    }

    public long getAccountId() {
        return accountId;
    }

    public long getVmId() {
        return vmId;
    }

    public String getHandlerName() {
        return handlerName;
    }
}

==> apache-cloudstack-4.19.0.0-src.tar.bz2: apache-cloudstack-4.19.0.0-src/engine/components-api/src/main/java/com/cloud/vm/VmWork.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
package com.cloud.vm;

import java.io.Serializable;

public class VmWork implements Serializable {
    private static final long serialVersionUID = -6946320465729853589L;

    long userId;
    long accountId;
    long vmId;

    String handlerName;

    public VmWork(long userId, long accountId, long vmId, String handlerName) {
        this.userId = userId;
        this.accountId = accountId;
        this.vmId = vmId;
        this.handlerName = handlerName;
    }

    public VmWork(VmWork vmWork) {
        this.userId = vmWork.getUserId();
        this.accountId = vmWork.getAccountId();
        this.vmId = vmWork.getVmId();
        this.handlerName = vmWork.getHandlerName();
    }

    public long getUserId() {
        return userId;
    }

    public long getAccountId() {
        return accountId;
    }

    public long getVmId() {
        return vmId;
    }

    public String getHandlerName() {
        return handlerName;
    }
}
